==> nextcloud-32.0.0p0.tgz: nextcloud/lib/l10n/sw.js <==
OC.L10N.register(
    "lib",
    {
    "Other activities" : "Other activities",
    "%1$s and %2$s" : "%1$s na %2$s",
    "Authentication" : "Uthibitisho",
    "Unknown filetype" : "Aina ya faili haijulikani",
    "Invalid image" : "Taswira si halisi",
    "Avatar image is not square" : "Avatar image is not square",
    "Files" : "Mafaili",
    "View profile" : "Angalia wasifu",
    "Local time: %s" : "Muda wa kawaida: %s",
    "_%n day ago_::_%n days ago_" : ["%n day ago","%n days ago"],
    "_%n year ago_::_%n years ago_" : ["%n year ago","%n years ago"],
    "_%n hour ago_::_%n hours ago_" : ["%n hour ago","%n hours ago"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute ago","%n minutes ago"],
    "seconds ago" : "sukunde zilizopita",
    "%1$s (renamed)" : "%1$s (iliyopew jina jipya)",
    "renamed file" : "Faili iliyopewa jina jipya",
    "Filenames must not end with \"%1$s\"." : "Majina ya faili hayapaswi kuishia na \"%1$s\"",
    "File already exists" : "Faili lipo tayari",
    "Templates" : "Violezo",
    "Filename contains at least one invalid character" : "Filename contains at least one invalid character",
    "__language_name__" : "_lugha_jina_",
    "Appearance and accessibility" : "Appearance and accessibility",
    "Apps" : "Maombi",
    "Settings" : "Mipangilio",
    "Log out" : "Ondoka",
    "Accounts" : "Akaunti",
    "Bluesky" : "Bluesky",
    "Email" : "Barua pepe",
    "Phone" : "Simu",
    "Twitter" : "Twitter",
    "Website" : "Wavuti",
    "Address" : "Anwani",
    "About" : "Kuhusu",
    "Display name" : "Display name",
    "Headline" : "Headline",
    "Additional settings" : "Mipangilio ya nyongeza",
    "%1$s shared %2$s with you" : "%1$s ameshirikisha %2$s na wewe",
    "Open %s" : "Fungua %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s shared %2$s with you and wants to add:",
    "%1$s shared %2$s with you and wants to add" : "%1$s shared %2$s with you and wants to add",
    "%s added a note to a file shared with you" : "%s added a note to a file shared with you",
    "Unknown share type" : "Unknown share type",
    "You are not allowed to share %s" : "You are not allowed to share %s",
    "Sharing %s failed, because this item is already shared with the account %s" : "Sharing %s failed, because this item is already shared with the account %s",
    "Input text" : "Input text",
    "Sunday" : "Jumapili",
    "Monday" : "Jumatatu",
    "Tuesday" : "Jumanne",
    "Wednesday" : "Jumatano",
    "Thursday" : "Alhamisi",
    "Friday" : "Ijumaa",
    "Saturday" : "Jumamosi",
    "January" : "Mwezi wa kwanza",
    "February" : "Mwezi wa pili",
    "March" : "Mwezi wa tatu",
    "April" : "Mwezi wa nne",
    "May" : "Mwezi wa tano",
    "June" : "Mwezi wa sita",
    "July" : "Mwezi wa saba",
    "August" : "Mwezi wa nane",
    "September" : "Mwezi wa tisa",
    "October" : "Mwezi wa kumi",
    "November" : "Mwezi wa kumi na moja",
    "December" : "Mwezi wa kumi na mbili",
    "a safe home for all your data" : "a safe home for all your data",
    "Authentication error" : "Hitilafu ya uthibitishaji",
    "Storage is temporarily not available" : "Uhifadhi haupo kwa muda",
    "Images" : "Picha",
    "Question" : "Swali",
    "Generated response" : "Generated response",
    "Voice chat with the assistant" : "Voice chat with the assistant",
    "System prompt" : "System prompt",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Define rules and assumptions that the assistant should follow during the conversation.",
    "Chat voice message" : "Chat voice message",
    "Chat history" : "Chat history",
    "Input transcript" : "Input transcript",
    "Transcription of the audio input" : "Transcription of the audio input",
    "Response voice message" : "Response voice message",
    "The generated voice response as part of the conversation" : "The generated voice response as part of the conversation",
    "Output transcript" : "Output transcript",
    "Transcription of the audio output" : "Transcription of the audio output",
    "Transcribe audio" : "Transcribe audio",
    "Audio input" : "Audio input",
    "Confirmation" : "Uthibitisho",
    "Generate image" : "Generate image",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Describe the image you want to generate",
    "Describe a task that you want the assistant to do or ask a question" : "Describe a task that you want the assistant to do or ask a question",
    "Change Tone" : "Change Tone",
    "Write a text that you want the assistant to rewrite in another tone." : "Write a text that you want the assistant to rewrite in another tone.",
    "Desired tone" : "Desired tone",
    "In which tone should your text be rewritten?" : "In which tone should your text be rewritten?",
    "The rewritten text in the desired tone, written by the assistant:" : "The rewritten text in the desired tone, written by the assistant:",
    "Chat" : "Chat",
    "The history of chat messages before the current message, starting with a message by the user" : "The history of chat messages before the current message, starting with a message by the user",
    "Text" : "Maandishi",
    "Summarize" : "Summarize",
    "Summary" : "Muhtasari",
    "Translate" : "Tafsiri",
    "Result" : "Result"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1.tgz: nextcloud/lib/l10n/sw.js <==
OC.L10N.register(
    "lib",
    {
    "Other activities" : "Other activities",
    "%1$s and %2$s" : "%1$s na %2$s",
    "Authentication" : "Uthibitisho",
    "Unknown filetype" : "Aina ya faili haijulikani",
    "Invalid image" : "Taswira si halisi",
    "Avatar image is not square" : "Avatar image is not square",
    "Files" : "Mafaili",
    "View profile" : "Angalia wasifu",
    "Local time: %s" : "Muda wa kawaida: %s",
    "_%n day ago_::_%n days ago_" : ["%n day ago","%n days ago"],
    "_%n year ago_::_%n years ago_" : ["%n year ago","%n years ago"],
    "_%n hour ago_::_%n hours ago_" : ["%n hour ago","%n hours ago"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute ago","%n minutes ago"],
    "seconds ago" : "sukunde zilizopita",
    "%1$s (renamed)" : "%1$s (iliyopew jina jipya)",
    "renamed file" : "Faili iliyopewa jina jipya",
    "Filenames must not end with \"%1$s\"." : "Majina ya faili hayapaswi kuishia na \"%1$s\"",
    "File already exists" : "Faili lipo tayari",
    "Templates" : "Violezo",
    "Filename contains at least one invalid character" : "Filename contains at least one invalid character",
    "__language_name__" : "_lugha_jina_",
    "This is an automatically sent email, please do not reply." : "This is an automatically sent email, please do not reply.",
    "Appearance and accessibility" : "Appearance and accessibility",
    "Apps" : "Maombi",
    "Settings" : "Mipangilio",
    "Log out" : "Ondoka",
    "Accounts" : "Akaunti",
    "Bluesky" : "Bluesky",
    "Email" : "Barua pepe",
    "Phone" : "Simu",
    "Twitter" : "Twitter",
    "Website" : "Wavuti",
    "Address" : "Anwani",
    "About" : "Kuhusu",
    "Display name" : "Display name",
    "Headline" : "Headline",
    "Additional settings" : "Mipangilio ya nyongeza",
    "%1$s shared %2$s with you" : "%1$s ameshirikisha %2$s na wewe",
    "Open %s" : "Fungua %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s shared %2$s with you and wants to add:",
    "%1$s shared %2$s with you and wants to add" : "%1$s shared %2$s with you and wants to add",
    "%s added a note to a file shared with you" : "%s added a note to a file shared with you",
    "Unknown share type" : "Unknown share type",
    "You are not allowed to share %s" : "You are not allowed to share %s",
    "Sharing %s failed, because this item is already shared with the account %s" : "Sharing %s failed, because this item is already shared with the account %s",
    "Input text" : "Input text",
    "Sunday" : "Jumapili",
    "Monday" : "Jumatatu",
    "Tuesday" : "Jumanne",
    "Wednesday" : "Jumatano",
    "Thursday" : "Alhamisi",
    "Friday" : "Ijumaa",
    "Saturday" : "Jumamosi",
    "January" : "Mwezi wa kwanza",
    "February" : "Mwezi wa pili",
    "March" : "Mwezi wa tatu",
    "April" : "Mwezi wa nne",
    "May" : "Mwezi wa tano",
    "June" : "Mwezi wa sita",
    "July" : "Mwezi wa saba",
    "August" : "Mwezi wa nane",
    "September" : "Mwezi wa tisa",
    "October" : "Mwezi wa kumi",
    "November" : "Mwezi wa kumi na moja",
    "December" : "Mwezi wa kumi na mbili",
    "a safe home for all your data" : "a safe home for all your data",
    "Authentication error" : "Hitilafu ya uthibitishaji",
    "Storage is temporarily not available" : "Uhifadhi haupo kwa muda",
    "Analyze images" : "Analyze images",
    "Ask a question about the given images." : "Ask a question about the given images.",
    "Images" : "Picha",
    "Images to ask a question about" : "Images to ask a question about",
    "Question" : "Swali",
    "Generated response" : "Generated response",
    "The answer to the question" : "The answer to the question",
    "Voice chat with the assistant" : "Voice chat with the assistant",
    "System prompt" : "System prompt",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Define rules and assumptions that the assistant should follow during the conversation.",
    "Chat voice message" : "Chat voice message",
    "Chat history" : "Chat history",
    "Input transcript" : "Input transcript",
    "Transcription of the audio input" : "Transcription of the audio input",
    "Response voice message" : "Response voice message",
    "The generated voice response as part of the conversation" : "The generated voice response as part of the conversation",
    "Output transcript" : "Output transcript",
    "Transcription of the audio output" : "Transcription of the audio output",
    "Transcribe audio" : "Transcribe audio",
    "Audio input" : "Audio input",
    "Confirmation" : "Uthibitisho",
    "Generate image" : "Generate image",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Describe the image you want to generate",
    "Generate speech" : "Generate speech",
    "Generate speech from a transcript" : "Generate speech from a transcript",
    "Describe a task that you want the assistant to do or ask a question" : "Describe a task that you want the assistant to do or ask a question",
    "Change Tone" : "Change Tone",
    "Write a text that you want the assistant to rewrite in another tone." : "Write a text that you want the assistant to rewrite in another tone.",
    "Desired tone" : "Desired tone",
    "In which tone should your text be rewritten?" : "In which tone should your text be rewritten?",
    "The rewritten text in the desired tone, written by the assistant:" : "The rewritten text in the desired tone, written by the assistant:",
    "Chat" : "Chat",
    "The history of chat messages before the current message, starting with a message by the user" : "The history of chat messages before the current message, starting with a message by the user",
    "Text" : "Maandishi",
    "Summarize" : "Summarize",
    "Summary" : "Muhtasari",
    "Translate" : "Tafsiri",
    "Result" : "Result"
},
"nplurals=2; plural=(n != 1);");
